var NAVTREEINDEX5 =
{
"permission_8h.html#aa6b729cf828ec6417f5ba997560fda2b":[11,0,49,9],
"permission_8h_source.html":[11,0,49],
"pipewire_8c.html":[11,0,50],
"pipewire_8c.html#a5432ea68283040ae9df24ebefe6414aa":[11,0,50,5],
"pipewire_8c.html#aa060eea150eca4951bf30b2738493912":[11,0,50,10],
"pipewire_8c.html#abfa925ac473c041c452e6d2287e77776":[11,0,50,9],
"pipewire_8c.html#ac0edd7fd875859cef79624861e212cc8":[11,0,50,8],
"pipewire_8c.html#acbb97d3ccaef2d8793ec48242324bf15":[11,0,50,12],
"pipewire_8c.html#ad6b599f28dfb2e60a14ac4cf01d4c18c":[11,0,50,11],
"pipewire_8c.html#adc79f7ce98fb706a36eb8a32de61b20c":[11,0,50,7],
"pipewire_8c.html#add0a31293ff259daa9029be346321392":[11,0,50,6],
"pipewire_8c.html#ae55b0f7a82aa61d5eb34593565176036":[11,0,50,4],
"pipewire_8h.html":[11,0,51],
"pipewire_8h.html#a06c879b2d800579f4724109054368d99":[11,0,51,10],
"pipewire_8h.html#a0a42d8f153fc58df733f74e5bf9af251":[11,0,51,7],
"pipewire_8h.html#a0b5efe6f38693683c07c4495bfcce6c4":[11,0,51,8],
"pipewire_8h.html#a245d94286ccbb5c23cec4448cc7070f0":[11,0,51,9],
"pipewire_8h.html#a4a582dbda1862c28b2eb70f50696cfc3":[11,0,51,6],
"pipewire_8h.html#a4efeba27bea1dc8d9188b8e49b3bd1b0":[11,0,51,2],
"pipewire_8h.html#a5cb61aa7df1b5fc780b2df1dd1d576b6":[11,0,51,5],
"pipewire_8h.html#a7f855ab509d6e01e13cf561968a4d1b6":[11,0,51,3],
"pipewire_8h.html#acc287aaae982260a49eeac97f27a8227":[11,0,51,0],
"pipewire_8h.html#accacb9b931e5e7d72c02987939f4edfd":[11,0,51,11],
"pipewire_8h.html#ae5e843dfd1edbf7204e6b40bbeb590a2":[11,0,51,4],
"pipewire_8h.html#af3d7686492ea5032eb135cddf21d3da2":[11,0,51,12],
"pipewire_8h.html#afa6045cd7391b467af4575c6752d6c4e":[11,0,51,1],
"pipewire_8h_source.html":[11,0,51],
"port_8h.html":[11,0,52],
"port_8h.html#a08be9849ba07abfd630fcc2b9094e132":[11,0,52,20],
"port_8h.html#a0a2b3393a17045c7f8a6ff004c8c7f33":[11,0,52,14],
"port_8h.html#a0f310d02527226da27151627692f999b":[11,0,52,11],
"port_8h.html#a1ed9c2e11f128b205fa467a2c0f19fe1":[11,0,52,16],
"port_8h.html#a2d08d6e2358afc05ca212a0258fb6a26":[11,0,52,22],
"port_8h.html#a32a9f01e1dde49d9c5b6f64efe7af6e5":[11,0,52,21],
"port_8h.html#a3e912fde083fd69eca50d503c041eabb":[11,0,52,12],
"port_8h.html#a5c505757aec81210eabf84b1f9593e70":[11,0,52,15],
"port_8h.html#a65cece0b739dc2a020a9ded0b26a22a3":[11,0,52,17],
"port_8h.html#a6ab4af1a18861478a1a9c24f3f59ea79":[11,0,52,24],
"port_8h.html#a6e316525982a94659dfd8b86d9090c02":[11,0,52,8],
"port_8h.html#a7458b44dfe9ccfb564276d814a49e94a":[11,0,52,23],
"port_8h.html#a866d33374688faec738124490db2877e":[11,0,52,10],
"port_8h.html#a9ca65febfd5440fa24c17ae89da5c0bd":[11,0,52,13],
"port_8h.html#ab2082f9bafca5d7d9ff6c53fb3431823":[11,0,52,3],
"port_8h.html#ac245481d75b73061398575ed44ab3e07":[11,0,52,5],
"port_8h.html#ac5541bb77b42b3e6d41d4ee9b4c06b6f":[11,0,52,6],
"port_8h.html#ac556c0b1548946709e9e99daa8b52b1b":[11,0,52,9],
"port_8h.html#ac8fe785592185f71666d2d03903cc367":[11,0,52,4],
"port_8h.html#ad14c54cfcc288a9b8b8f01fe54a86a5d":[11,0,52,19],
"port_8h.html#ada3484ae34475c97571c091b7494d7b3":[11,0,52,18],
"port_8h.html#adfbc0811753d8dface115a011a356360":[11,0,52,25],
"port_8h.html#af355e07f1fb54c06af8e1040c47bd1c3":[11,0,52,7],
"port_8h_source.html":[11,0,52],
"properties_8c.html":[11,0,53],
"properties_8c.html#a45bb0212063f3daf407c3896f376e7b3":[11,0,53,0],
"properties_8h.html":[11,0,54],
"properties_8h.html#a020d2bd083e845bbfa3d2366d8c7ffec":[11,0,54,5],
"properties_8h.html#a2be4b4644571899e12734d1f86551d42":[11,0,54,2],
"properties_8h.html#a375f258e0fd46fb55233eeb0280ef5d5":[11,0,54,1],
"properties_8h.html#a5da7715ec88bf4363973a9af40668cc1":[11,0,54,8],
"properties_8h.html#a680ebd10d43086aeb159f3b99cb7b381":[11,0,54,15],
"properties_8h.html#a8728cb2a61fb1b387b074f918518464d":[11,0,54,13],
"properties_8h.html#a8ef83913ccf2abb4432ba0ebd3230516":[11,0,54,11],
"properties_8h.html#a8f7a5b70d523cf25f10495830012492a":[11,0,54,4],
"properties_8h.html#a900f0a2675dc8002cd99863565c38751":[11,0,54,10],
"properties_8h.html#a92deca42395043a47ba2a375a946baf4":[11,0,54,12],
"properties_8h.html#aab902808587304fc502c8f3e7f9f876b":[11,0,54,9],
"properties_8h.html#ab959f3151e3886da6a1170310441f48f":[11,0,54,14],
"properties_8h.html#abe3bcabf87a8e0dc65fb9abb5ea60961":[11,0,54,3],
"properties_8h.html#ac11d34de86e40476b46f614220bf0922":[11,0,54,7],
"properties_8h.html#af140f16cfea836559f783f942cfa247d":[11,0,54,6],
"properties_8h_source.html":[11,0,54],
"protocol_8c.html":[11,0,55],
"protocol_8c.html#a1404d65cfb4a66704ca27407f5640cd1":[11,0,55,7],
"protocol_8c.html#a2a84f415542c753f4ee146481b33c23d":[11,0,55,8],
"protocol_8c.html#a34a51785cdcd416d5974b6c338d64657":[11,0,55,4],
"protocol_8c.html#a36b16ebb431f39b8439ca456bec7fe87":[11,0,55,1],
"protocol_8c.html#a47f2e62c0dbebc787052c165afcada0e":[11,0,55,0],
"protocol_8c.html#a7321365269fdc141a1995b2df56161c6":[11,0,55,5],
"protocol_8c.html#a8cd83927fc5105e58443dcd0f74bddff":[11,0,55,6],
"protocol_8c.html#a9638585c7880eb5dad87cc14c68cf509":[11,0,55,9],
"protocol_8c.html#adaa5ef11c165140322c7f6af484ddccf":[11,0,55,3],
"protocol_8c.html#adacff2f9c7a8c1022b1111d9ecfea7d2":[11,0,55,2],
"protocol_8c.html#af1ff8145055154bee0c4bd8db6310c46":[11,0,55,10],
"protocol_8h.html":[11,0,56],
"protocol_8h.html#a0026bb6385904327d20a8dfcf982ba62":[11,0,56,6],
"protocol_8h.html#a037815ec8a8996495c6935b2d8397765":[11,0,56,20],
"protocol_8h.html#a0d1b9030d4215a9b2b9da1fe3f5cea93":[11,0,56,27],
"protocol_8h.html#a10397b3ea74c80703140242313ab52df":[11,0,56,14],
"protocol_8h.html#a253136c71f02f82d59fd79c78c40fe65":[11,0,56,21],
"protocol_8h.html#a28d837f48d3ee4ae37c11631bbaf6712":[11,0,56,29],
"protocol_8h.html#a3b9d1f2afdf848863a84c7f2c825dc32":[11,0,56,5],
"protocol_8h.html#a4b8a7c184d8756e4864538f16a60bec3":[11,0,56,22],
"protocol_8h.html#a4d8f6852ba390ba826744d18b58c4021":[11,0,56,19],
"protocol_8h.html#a56a619809f144fb3e27ac9e0644e3830":[11,0,56,7],
"protocol_8h.html#a64a3293decdd3cfefc715c040180368a":[11,0,56,13],
"protocol_8h.html#a6673120bfc643d6cbeea97535873b4f0":[11,0,56,9],
"protocol_8h.html#a6c57711ce8eee785b967ed0487a2fe3b":[11,0,56,15],
"protocol_8h.html#a6d58875f54dbf541b969c5911b802311":[11,0,56,23],
"protocol_8h.html#a82db853682f87cab9986d4e3f923f2d0":[11,0,56,24],
"protocol_8h.html#a910bf17e4410db6f10055da489451604":[11,0,56,16],
"protocol_8h.html#a91126ea5ca35fb743c9fd04d27316fe1":[11,0,56,12],
"protocol_8h.html#aaba33660d98b865fb0ea4898ab6f8fe8":[11,0,56,28],
"protocol_8h.html#ac2742efc503c7a6e04238bd9a94af35e":[11,0,56,18],
"protocol_8h.html#ac3c7dce722800fb4c8ab54267ef6303a":[11,0,56,10],
"protocol_8h.html#ad3a30029abadec4f4b76ae2cb28a4585":[11,0,56,8],
"protocol_8h.html#ae14bc734b0ea2f0cd081716a552d3b07":[11,0,56,26],
"protocol_8h.html#aeae48475b735761c22837afd53e2ce9e":[11,0,56,11],
"protocol_8h.html#aedaad565d0021ebcffe1b8699d150174":[11,0,56,25],
"protocol_8h.html#af2da98ab0dabd83d281ac8e4495d43d8":[11,0,56,17],
"protocol_8h_source.html":[11,0,56],
"proxy_8c.html":[11,0,57],
"proxy_8c.html#a0230e50305d6532135262f047d78d589":[11,0,57,8],
"proxy_8c.html#a040756d38e9005b9e0594d3b577a71c6":[11,0,57,15],
"proxy_8c.html#a052431961e2ec5f5c2d6281371b51d76":[11,0,57,14],
"proxy_8c.html#a069f5c4b4ce0b793cae45f42a80402f4":[11,0,57,5],
"proxy_8c.html#a23bac343d4e384a18a2af8309c45427c":[11,0,57,12],
"proxy_8c.html#a24a682b4ae829a3df5b15d81413117b7":[11,0,57,16],
"proxy_8c.html#a2991ce1ad533d4538c1ff0319040ca97":[11,0,57,13],
"proxy_8c.html#a300bdaa7161aa447a4eba6a739715352":[11,0,57,9],
"proxy_8c.html#a47f2e62c0dbebc787052c165afcada0e":[11,0,57,0],
"proxy_8c.html#a5a4e33d3bd6d62ca06fa64999ecb8791":[11,0,57,1],
"proxy_8c.html#a6224e5d633541e2b174202a2cce954f4":[11,0,57,10],
"proxy_8c.html#a67e58eecfbb34d685afa175730bf6b48":[11,0,57,6],
"proxy_8c.html#a975552b85dda76a790be32704f7039c8":[11,0,57,7],
"proxy_8c.html#a99c20bae91db208101db6c41eb1ba3f3":[11,0,57,11],
"proxy_8c.html#aa1ffe7f68e1007f515834cd60d7f38a0":[11,0,57,4],
"proxy_8c.html#ab78447e86c8400d4837f02aecbd1b76c":[11,0,57,19],
"proxy_8c.html#ac3860a60d2600abb6808ba5241df7f3a":[11,0,57,18],
"proxy_8c.html#ac3f1077584142c2fa0648fa89179d85f":[11,0,57,3],
"proxy_8c.html#ac598b9d43036d387eae8f88840767cf8":[11,0,57,17],
"proxy_8c.html#acde8eeec95cd202da19496a6416d5b46":[11,0,57,2],
"proxy_8h.html":[11,0,58],
"proxy_8h.html#a00ecf59a7b69d43ae4106312174d709b":[11,0,58,19],
"proxy_8h.html#a01735abb03506ca5b939744c2679e8ae":[11,0,58,5],
"proxy_8h.html#a0cb18a01022f447b12c4fd0b9d0155cb":[11,0,58,1],
"proxy_8h.html#a0ddbfcd98c2c6672cc9599f0f35f5c1d":[11,0,58,15],
"proxy_8h.html#a145c4c84bc198084c219d56c352dafb7":[11,0,58,6],
"proxy_8h.html#a27f6e2e1b9ccaca199b450b1336ef731":[11,0,58,18],
"proxy_8h.html#a5950a9b370047e0ac45989a52a2f47ed":[11,0,58,12],
"proxy_8h.html#a5a1ea70103be68200f15ceff8c89f7bc":[11,0,58,8],
"proxy_8h.html#a68572822ba2f4e2160e81c4f892ac346":[11,0,58,10],
"proxy_8h.html#a71704262db96f9b4e87d78beabdd3754":[11,0,58,13],
"proxy_8h.html#a7848850f682e1a7fddc0f1c82b4acc4c":[11,0,58,9],
"proxy_8h.html#a8dd7c3044529e15a8fcc8c1034bbb102":[11,0,58,4],
"proxy_8h.html#a8f5ec1968479b4955dbb6988e12fc130":[11,0,58,3],
"proxy_8h.html#a9490301016b057af0551c759696c374c":[11,0,58,20],
"proxy_8h.html#a9ace4e7667587147f9970d41cafac327":[11,0,58,14],
"proxy_8h.html#aa4790d3d0254680598e0c9a19f9107a3":[11,0,58,11],
"proxy_8h.html#aa93c46b89222bd416df4f4c058f89c21":[11,0,58,2],
"proxy_8h.html#ab74bbe87b946bf5f5189c14203642599":[11,0,58,16],
"proxy_8h.html#ad3231c616d6b193d24d3bd0895670daf":[11,0,58,17],
"proxy_8h.html#adb7836fa36fc664449def4b9ea27c7ed":[11,0,58,7],
"proxy_8h_source.html":[11,0,58],
"resource_8c.html":[11,0,59],
"resource_8c.html#a0d95e95f9b243ccfb01d72a4b830b723":[11,0,59,12],
"resource_8c.html#a2f7b9147420545849b8dfe0854571ca6":[11,0,59,14],
"resource_8c.html#a3a9a54881991621284af6adaddbe8fc3":[11,0,59,5],
"resource_8c.html#a47f2e62c0dbebc787052c165afcada0e":[11,0,59,0],
"resource_8c.html#a51c7cc27c6480a9f90aa46f682f78fbb":[11,0,59,18],
"resource_8c.html#a60ec1e889a29a0d44b21913ba23646ee":[11,0,59,20],
"resource_8c.html#a7298546785241e4a33c19487ad705542":[11,0,59,7],
"resource_8c.html#a77aff410edb984bf14e2d2787c567480":[11,0,59,3],
"resource_8c.html#a8b8380e07403b42b322a2b0aaee65048":[11,0,59,15],
"resource_8c.html#a9718aa335fbb9c1b8dfc605f05127078":[11,0,59,11],
"resource_8c.html#a9835c868a6c858d7c616d596b6b89074":[11,0,59,8],
"resource_8c.html#aac985444e90eaff49c41b526e261ed9a":[11,0,59,17],
"resource_8c.html#ab264bc9e31ca19a13128fd9a86a9a89c":[11,0,59,10],
"resource_8c.html#ac13edd4bf3ef57082cdff714e44f34d7":[11,0,59,6],
"resource_8c.html#ac56732c3393fe64009d30f2ccc340faa":[11,0,59,9],
"resource_8c.html#ad86aece7b0917770f92323490b984d3d":[11,0,59,4],
"resource_8c.html#adff1fa3a0954521f6abb9a5a0722e1da":[11,0,59,19],
"resource_8c.html#ae052a184a74219884daf783817e48789":[11,0,59,2],
"resource_8c.html#ae7534e38e4825d07fe8330fa99f6fb62":[11,0,59,13],
"resource_8c.html#af2660cf560a8b1df8d6dab389ab22d1f":[11,0,59,16],
"resource_8c.html#afd32e674691ae1c261494fb1e177e550":[11,0,59,1],
"resource_8h.html":[11,0,60],
"resource_8h.html#a119a41be865f03ef8736977acba8a323":[11,0,60,5],
"resource_8h.html#a11df048744c827fbefc328ec7b9dc135":[11,0,60,2],
"resource_8h.html#a1774043ade001a33ab65e5fbabd5d89e":[11,0,60,23],
"resource_8h.html#a2939579219c911b29702d145b9cfc1df":[11,0,60,12],
"resource_8h.html#a332bee9e00671e80bd1d897551aa065d":[11,0,60,16],
"resource_8h.html#a400f8bdb7b5779db732e3f224b87e07e":[11,0,60,3],
"resource_8h.html#a6000827e0dc8637b0538f75800c0f581":[11,0,60,20],
"resource_8h.html#a6006f7393419cb5c874398f2954ac1b4":[11,0,60,11],
"resource_8h.html#a61e286d92a2f528ebe48cb1436ac4eba":[11,0,60,1],
"resource_8h.html#a6ae5c51e7cab79f755e36c8746973da3":[11,0,60,18],
"resource_8h.html#a6c7d1b4c88e189e426d762c095e5088e":[11,0,60,10],
"resource_8h.html#a961e8d61d007ece23ae04afd08e320dc":[11,0,60,15],
"resource_8h.html#a98bbacb715f5469dcc14a071d14b3883":[11,0,60,8],
"resource_8h.html#a9edff924e88ea8ae7d0b74065ad7415a":[11,0,60,22],
"resource_8h.html#aa2d8c1bd7008acbd8fe30e47e6c08d3f":[11,0,60,6],
"resource_8h.html#aab37d37e596381fec6da22531f78d7bb":[11,0,60,14],
"resource_8h.html#aadff480a3e38ec195e07567c1e46ab54":[11,0,60,4],
"resource_8h.html#ab9e159d75b7efe39bd53b64055244092":[11,0,60,7],
"resource_8h.html#ac7d13ba52bc1796d4baca39ddc4a6f0c":[11,0,60,17],
"resource_8h.html#aca22b4d01cbb654308199df25efba373":[11,0,60,9],
"resource_8h.html#ae022953f35be3767c44de0c43fa572e2":[11,0,60,19],
"resource_8h.html#ae32b47d6f25f56678385b0c269e8c3e0":[11,0,60,21],
"resource_8h.html#af3044f96f645e97035b87d3b37d3e017":[11,0,60,24],
"resource_8h.html#af8fe4859dd6826d5eb6c7e28f5519215":[11,0,60,13],
"resource_8h_source.html":[11,0,60],
"stream_8c.html":[11,0,61],
"stream_8c.html#a0aa398ef7b09697a0e48719b27112614":[11,0,61,27],
"stream_8c.html#a0d2ad73d654de2bc11afe6847474afcb":[11,0,61,34],
"stream_8c.html#a1676b48e222d9bcf50fd21374ea121c2":[11,0,61,6],
"stream_8c.html#a1f024c54b2e507824ea0f5441f5b2af4":[11,0,61,32],
"stream_8c.html#a1ffbabb0a49127dc56c22e466c2903e7":[11,0,61,23],
"stream_8c.html#a272af3c2d61d7fb25dc2ab076dc044de":[11,0,61,16],
"stream_8c.html#a2ab8d1619a5739153a3bff01e6c6788e":[11,0,61,24],
"stream_8c.html#a40ad70cc6e2125af9340a4bc26a83764":[11,0,61,10],
"stream_8c.html#a41326ea19a5ae0815a63f0db0a114dfc":[11,0,61,8],
"stream_8c.html#a430884fd1ac91c74cb5574400a619216":[11,0,61,17],
"stream_8c.html#a47f2e62c0dbebc787052c165afcada0e":[11,0,61,11],
"stream_8c.html#a4ce79c03126c9b7166c33cab212283ce":[11,0,61,20],
"stream_8c.html#a54dfe4670ac6de650a3926b68cadbdb8":[11,0,61,26],
"stream_8c.html#a65b66a8987387a5894d8414e9573a880":[11,0,61,21],
"stream_8c.html#a664d10ae36c157ecca989fe0c562017b":[11,0,61,22],
"stream_8c.html#a7781bc9613ec655352585fb1bac2595d":[11,0,61,9],
"stream_8c.html#a7d77dd629b7e3a8c6d28cccb93df21e4":[11,0,61,28],
"stream_8c.html#a89bba79201856c41ea53bd01e65f6438":[11,0,61,7],
"stream_8c.html#a93f84e7cab1f289398e277aec50a63b8":[11,0,61,15],
"stream_8c.html#ab41e1c2fa4274c6916e51655e481dd6e":[11,0,61,33],
"stream_8c.html#ac1d281db6111363227781192d2eb56c7":[11,0,61,31],
"stream_8c.html#ac9d87c5da34f1357637309ffdd1185cb":[11,0,61,19],
"stream_8c.html#ad05e907fadaaa1cd21062cd0bb8701a1":[11,0,61,29],
"stream_8c.html#ad5e65901bc4e01fe66908de6eb983b74":[11,0,61,18],
"stream_8c.html#ae19fa7dc034a052b0ee1f582e8a949c0":[11,0,61,12],
"stream_8c.html#ae8a3753316267cd885e875ae7fbd3c91":[11,0,61,25],
"stream_8c.html#aebbd77924da3cf1c98f8552178f42da6":[11,0,61,14],
"stream_8c.html#af86bc65adf0e4c18f8ea3c09f5e62d9d":[11,0,61,30],
"stream_8c.html#afeafcb95f3bc48b81410bf7848473a8f":[11,0,61,13],
"stream_8h.html":[11,0,62],
"stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106":[11,0,62,5],
"stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106a2912e7520b8eb0aa5e4a5ca275f10d3b":[11,0,62,5,2],
"stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106a615348212b647ad5d30313536ed6e125":[11,0,62,5,3],
"stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106a73692ffb4a18142df04772cf3783410c":[11,0,62,5,4],
"stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106a79f1bdb249e79c7e71cf46759936768f":[11,0,62,5,7],
"stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106a87c6bfacd40d4f797505fbc22bd2b9da":[11,0,62,5,6],
"stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106ab111b3fc3e1d3c1c439a65dc85a3ce20":[11,0,62,5,8],
"stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106ab648fa0c0c7adf6aa3139eddc3a9cd7c":[11,0,62,5,1],
"stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106ab95a612ea82e3d928b5d2971bcd96465":[11,0,62,5,9],
"stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106ad569b3a7085e21df1236651fd3388a22":[11,0,62,5,5],
"stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106aefcc7a31a05fa55c8cff7e686dd484ca":[11,0,62,5,0],
"stream_8h.html#a065b067d55def0d2c2cedf814a5c55d0":[11,0,62,18],
"stream_8h.html#a087a686c66c04e54742cc94c7a5e4e68":[11,0,62,13],
"stream_8h.html#a2d5e07833039ac7a202caaf297556f52":[11,0,62,16],
"stream_8h.html#a55c1224289e488e27f8d3b6e58abcd08":[11,0,62,17],
"stream_8h.html#a5ef987fd1903baa7eba9b10a8cbf5e97":[11,0,62,9],
"stream_8h.html#a751f41a0a5ce1ece31ec126b3cab4fd4":[11,0,62,11],
"stream_8h.html#a7a8eafa174549733293f11ec2c646827":[11,0,62,14]
};
